==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-management/src/main/java/org/apache/geode/management/api/ClusterManagementRealizationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.management.api;

import java.util.List;

/**
 * Thrown by {@link ClusterManagementService#create(AbstractConfiguration)}, update, and delete
 * operations
 * which have a possibility of "partial" failure.
 */
public class ClusterManagementRealizationException extends ClusterManagementException {
  private final ClusterManagementRealizationResult result;

  /**
   * for internal use only
   */
  public ClusterManagementRealizationException(ClusterManagementRealizationResult result) {
    super(result);
    this.result = result;
  }

  /**
   * A {@link ClusterManagementService#create(AbstractConfiguration)} operation may fail on all
   * members or
   * only some. This will return the per-member status.
   */
  public List<RealizationResult> getMemberStatuses() {
    return result.getMemberStatuses();
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-management/src/main/java/org/apache/geode/management/api/ClusterManagementRealizationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.management.api;

import java.util.List;

import org.apache.geode.management.configuration.AbstractConfiguration;

/**
 * Thrown by {@link ClusterManagementService#create(AbstractConfiguration)}, update, and delete
 * operations
 * which have a possibility of "partial" failure.
 */
public class ClusterManagementRealizationException extends ClusterManagementException {
  private final ClusterManagementRealizationResult result;

  /**
   * for internal use only
   *
   * @param result the {@link ClusterManagementRealizationResult} to set
   */
  public ClusterManagementRealizationException(ClusterManagementRealizationResult result) {
    super(result);
    this.result = result;
  }

  /**
   * A {@link ClusterManagementService#create(AbstractConfiguration)} operation may fail on all
   * members or
   * only some. This will return the per-member status.
   *
   * @return a list of {@link RealizationResult}s
   */
  public List<RealizationResult> getMemberStatuses() {
    return result.getMemberStatuses();
  }
}
